@@ -8,13 +8,10 @@ fn example() {
     struct Numbers(Vec<u32>);
 
     // use `From` trait
-    let mut my_favorite_numbers: Numbers = vec![].into();
-
-    // use inner APIs with `DerefMut` trait.
-    my_favorite_numbers.push(42);
+    let my_favorite_numbers: Numbers = vec![].into();
 
     // `FromIterator` allows this `collect()`
-    let doubled_numbers: Numbers = my_favorite_numbers.iter().map(|x| x * 2).collect();
+    let doubled_numbers: Numbers = my_favorite_numbers.0.iter().map(|x| x * 2).collect();
 
     // `HashMap` is also supported
     #[derive(Plural)]
@@ -27,7 +24,7 @@ fn example() {
     // use it in a `for` loop (`IntoIterator` trait)
     for (name, numbers) in favorite_numbers {
         // use Deref trait
-        println!("{} has {} favorite number(s)", name, numbers.len());
+        println!("{} has {} favorite number(s)", name, numbers.0.len());
     }
 }
 
@@ -47,36 +44,6 @@ fn vec_collect() {
     assert_eq!(std::iter::once(1).collect::<VecTuple>(), VecTuple(vec![1]));
 }
 
-#[test]
-fn vec_iter() {
-    let tuple = VecTuple(vec![1]);
-    let mut iter = tuple.iter();
-    let a: Option<&u8> = iter.next();
-    assert_eq!(a, Some(&1));
-    assert_eq!(iter.next(), None);
-}
-
-#[test]
-fn vec_iter_mut() {
-    let mut tuple = VecTuple(vec![1]);
-    let mut iter = tuple.iter_mut();
-    let a: Option<&mut u8> = iter.next();
-    assert_eq!(a, Some(&mut 1));
-    assert_eq!(iter.next(), None);
-}
-
-#[test]
-fn vec_deref() {
-    assert_eq!(VecTuple(vec![1, 2]).len(), 2);
-}
-
-#[test]
-fn vec_deref_mut() {
-    let mut extended = VecTuple(vec![1, 2]);
-    extended.extend(VecTuple(vec![3]));
-    assert_eq!(extended, VecTuple(vec![1, 2, 3]));
-}
-
 #[test]
 fn vec_into() {
     let vec: Vec<_> = VecTuple(vec![1]).into();
@@ -119,37 +86,6 @@ fn hash_map_collect() {
         HashMapTuple(HashMap::from_iter([(1, true)]))
     );
 }
-
-#[test]
-fn hash_map_iter() {
-    let tuple = HashMapTuple::from_iter([(1, true)]);
-    let mut iter = tuple.iter();
-    let a: Option<(&u8, &bool)> = iter.next();
-    assert_eq!(a, Some((&1, &true)));
-    assert_eq!(iter.next(), None);
-}
-
-#[test]
-fn hash_map_iter_mut() {
-    let mut tuple = HashMapTuple::from_iter([(1, true)]);
-    let mut iter = tuple.iter_mut();
-    let a: Option<(&u8, &mut bool)> = iter.next();
-    assert_eq!(a, Some((&1, &mut true)));
-    assert_eq!(iter.next(), None);
-}
-
-#[test]
-fn hash_map_deref() {
-    assert_eq!(HashMapTuple::from_iter([(1, true), (2, false)]).len(), 2);
-}
-
-#[test]
-fn hash_map_deref_mut() {
-    let mut extended = HashMapTuple::from_iter([(1, true)]);
-    extended.extend(HashMapTuple::from_iter([(2, false)]));
-    assert_eq!(extended, HashMapTuple::from_iter([(1, true), (2, false)]));
-}
-
 #[test]
 fn hash_map_into() {
     let hash_map: HashMap<_, _> = HashMapTuple::from_iter([(1, true)]).into();
